==> haskell-unixutils-1.54.3-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Unixutils
version:              1.54.3
visibility:           public
id:                   Unixutils-1.54.3-KJOORUrkHmT6KZ3EjmSb1F
key:                  Unixutils-1.54.3-KJOORUrkHmT6KZ3EjmSb1F
license:              BSD-3-Clause
maintainer:           David Fox <ddssff@gmail.com>
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  c4e76e6e171a8b356a63e6184fcb1a42
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unixutils
hs-libraries:         HSUnixutils-1.54.3-KJOORUrkHmT6KZ3EjmSb1F
extra-libraries:      crypt
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    process-extras-0.7.4-4NykvBWm4xhL9SpDQaXzAA
    pureMD5-2.1.4-6BAlx1YcRzfGjM1aVlHnl3
    regex-tdfa-1.3.2.4-76nazsu2jDf2z4IzA4PXWU unix-2.7.3
    zlib-0.7.0.0-5M03NfMqvh04F5NN11Rd2B

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.3-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Unixutils
version:              1.54.3
visibility:           public
id:                   Unixutils-1.54.3-6Ywb6x2Isra3O0DZhxQQDk
key:                  Unixutils-1.54.3-6Ywb6x2Isra3O0DZhxQQDk
license:              BSD-3-Clause
maintainer:           David Fox <ddssff@gmail.com>
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  8ef43e8b9d61970e730c4106351436a3
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Unixutils-1.54.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unixutils
hs-libraries:         HSUnixutils-1.54.3-6Ywb6x2Isra3O0DZhxQQDk
extra-libraries:      crypt
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    process-extras-0.7.4-Khs91oW3bCr63z6Rlg0Wxp
    pureMD5-2.1.4-6BAlx1YcRzfGjM1aVlHnl3
    regex-tdfa-1.3.2.4-B2W5oyAjPNNGy3A0Uip0eB unix-2.7.3
    zlib-0.7.0.0-2FkZGfzwBUc7WS0yLbO8rr

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
